@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-extra
 version: 1.1.11
-id: conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
-key: condu_5b3gTpaqLvlJEVDxa8oIzk
+id: conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+key: condu_JKRKhZMH92DBBvaX6faO4m
 license: MIT
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -23,11 +23,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.11
-hs-libraries: HSconduit-extra-1.1.11-5b3gTpaqLvlJEVDxa8oIzk
+hs-libraries: HSconduit-extra-1.1.11-JKRKhZMH92DBBvaX6faO4m
 depends:
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
@@ -39,8 +39,8 @@ depends:
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
-    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
 haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
